@@ -1,13 +1,34 @@
+/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
+/*
+   Copyright (C) 2010 Collabora Ltd
+
+   The Gnome Keyring Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+
+   The Gnome Keyring Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+
+   You should have received a copy of the GNU Library General Public
+   License along with the Gnome Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
+
+   Author: Stef Walter <stefw@collabora.co.uk>
+*/
 
 #include "config.h"
-#include "test-suite.h"
-
-#include "egg/egg-asn1x.h"
-#include "egg/egg-asn1-defs.h"
 
 #include "gcr/gcr.h"
 #include "gcr/gcr-internal.h"
 
+#include "egg/egg-asn1x.h"
+#include "egg/egg-asn1-defs.h"
+#include "egg/egg-testing.h"
+
 #include "gck/gck-mock.h"
 #include "gck/gck-test.h"
 
@@ -16,6 +37,7 @@
 
 #include <glib.h>
 
+#include <errno.h>
 #include <string.h>
 
 /* ---------------------------------------------------------------------------
@@ -42,7 +64,8 @@ typedef struct _MockCertificateClass {
 
 static void mock_certificate_iface (GcrCertificateIface *iface);
 G_DEFINE_TYPE_WITH_CODE (MockCertificate, mock_certificate, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (GCR_TYPE_CERTIFICATE, mock_certificate_iface));
+	G_IMPLEMENT_INTERFACE (GCR_TYPE_CERTIFICATE, mock_certificate_iface);
+);
 
 static void
 mock_certificate_init (MockCertificate *self)
@@ -95,34 +118,34 @@ mock_certificate_new (gconstpointer data, gsize n_data)
  * TESTS
  */
 
-static GcrCertificate *cert_self = NULL;
-static GcrCertificate *cert_ca = NULL;
-static GcrCertificate *cert_signed = NULL;
-static CK_FUNCTION_LIST funcs;
+typedef struct {
+	GcrCertificate *cert_self;
+	GcrCertificate *cert_ca;
+	GcrCertificate *cert_signed;
+	CK_FUNCTION_LIST funcs;
+} Test;
 
-TESTING_SETUP (certificate_chain)
+static void
+setup (Test *test, gconstpointer unused)
 {
 	GList *modules = NULL;
 	CK_FUNCTION_LIST_PTR f;
-	guchar *contents;
+	gchar *contents;
 	gsize n_contents;
 	const gchar *uris[2];
 	CK_RV rv;
 	GckModule *module;
 
-	/* Look for the config in the build directory */
-	_gcr_set_pkcs11_config_dir (TEST_CONFIG_DIR);
-
 	rv = gck_mock_C_GetFunctionList (&f);
 	gck_assert_cmprv (rv, ==, CKR_OK);
-	memcpy (&funcs, f, sizeof (funcs));
+	memcpy (&test->funcs, f, sizeof (test->funcs));
 
 	/* Open a session */
-	rv = (funcs.C_Initialize) (NULL);
+	rv = (test->funcs.C_Initialize) (NULL);
 	gck_assert_cmprv (rv, ==, CKR_OK);
 
 	g_assert (!modules);
-	module = gck_module_new (&funcs, 0);
+	module = gck_module_new (&test->funcs, 0);
 	modules = g_list_prepend (modules, module);
 	gcr_pkcs11_set_modules (modules);
 	uris[0] = GCK_MOCK_SLOT_ONE_URI;
@@ -132,18 +155,21 @@ TESTING_SETUP (certificate_chain)
 	gck_list_unref_free (modules);
 
 	/* A self-signed certificate */
-	contents = testing_data_read ("der-certificate.crt", &n_contents);
-	cert_self = gcr_simple_certificate_new (contents, n_contents);
+	if (!g_file_get_contents (SRCDIR "/files/der-certificate.crt", &contents, &n_contents, NULL))
+		g_assert_not_reached ();
+	test->cert_self = gcr_simple_certificate_new (contents, n_contents);
 	g_free (contents);
 
 	/* A signed certificate */
-	contents = testing_data_read ("dhansak-collabora.cer", &n_contents);
-	cert_signed = mock_certificate_new (contents, n_contents);
+	if (!g_file_get_contents (SRCDIR "/files/dhansak-collabora.cer", &contents, &n_contents, NULL))
+		g_assert_not_reached ();
+	test->cert_signed = mock_certificate_new (contents, n_contents);
 	g_free (contents);
 
 	/* The signer for the above certificate */
-	contents = testing_data_read ("collabora-ca.cer", &n_contents);
-	cert_ca = mock_certificate_new (contents, n_contents);
+	if (!g_file_get_contents (SRCDIR "/files/collabora-ca.cer", &contents, &n_contents, NULL))
+		g_assert_not_reached ();
+	test->cert_ca = mock_certificate_new (contents, n_contents);
 	g_free (contents);
 }
 
@@ -211,24 +237,21 @@ add_pinned_to_module (GcrCertificate *certificate, const gchar *purpose, const g
 	gck_mock_module_take_object (attrs);
 }
 
-TESTING_TEARDOWN (certificate_chain)
+static void
+teardown (Test *test, gconstpointer unused)
 {
 	CK_RV rv;
 
-	g_object_unref (cert_self);
-	cert_self = NULL;
+	g_object_unref (test->cert_self);
+	g_object_unref (test->cert_signed);
+	g_object_unref (test->cert_ca);
 
-	g_object_unref (cert_signed);
-	cert_signed = NULL;
-
-	g_object_unref (cert_ca);
-	cert_ca = NULL;
-
-	rv = (funcs.C_Finalize) (NULL);
+	rv = (test->funcs.C_Finalize) (NULL);
 	gck_assert_cmprv (rv, ==, CKR_OK);
 }
 
-TESTING_TEST (certificate_chain_new)
+static void
+test_new (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 
@@ -243,15 +266,16 @@ TESTING_TEST (certificate_chain_new)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_new_with_cert)
+static void
+test_new_with_cert (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GcrCertificate *check;
 	guint status, length;
 
 	chain = gcr_certificate_chain_new ();
-	gcr_certificate_chain_add (chain, cert_signed);
-	gcr_certificate_chain_add (chain, cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_ca);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_status (chain), ==,
 	                  GCR_CERTIFICATE_CHAIN_UNKNOWN);
@@ -264,19 +288,20 @@ TESTING_TEST (certificate_chain_new_with_cert)
 	g_assert_cmpuint (length, ==, 2);
 
 	check = gcr_certificate_chain_get_certificate (chain, 1);
-	g_assert (check == cert_ca);
+	g_assert (check == test->cert_ca);
 
 	/* Not yet completed */
 	check = gcr_certificate_chain_get_anchor (chain);
 	g_assert (check == NULL);
 
 	check = gcr_certificate_chain_get_endpoint (chain);
-	g_assert (check == cert_signed);
+	g_assert (check == test->cert_signed);
 
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_selfsigned)
+static void
+test_selfsigned (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -284,7 +309,7 @@ TESTING_TEST (certificate_chain_selfsigned)
 	chain = gcr_certificate_chain_new ();
 
 	/* Add a self-signed certificate */
-	gcr_certificate_chain_add (chain, cert_self);
+	gcr_certificate_chain_add (chain, test->cert_self);
 
 	if (!gcr_certificate_chain_build (chain, GCR_PURPOSE_CLIENT_AUTH,
 	                                  NULL, 0, NULL, &error))
@@ -297,7 +322,8 @@ TESTING_TEST (certificate_chain_selfsigned)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_incomplete)
+static void
+test_incomplete (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -305,7 +331,7 @@ TESTING_TEST (certificate_chain_incomplete)
 	chain = gcr_certificate_chain_new ();
 
 	/* Add a signed certificate */
-	gcr_certificate_chain_add (chain, cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_signed);
 
 	if (!gcr_certificate_chain_build (chain, GCR_PURPOSE_CLIENT_AUTH,
 	                                  NULL, 0, NULL, &error))
@@ -318,7 +344,8 @@ TESTING_TEST (certificate_chain_incomplete)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_empty)
+static void
+test_empty (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -338,7 +365,8 @@ TESTING_TEST (certificate_chain_empty)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_trim_extras)
+static void
+test_trim_extras (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -346,8 +374,8 @@ TESTING_TEST (certificate_chain_trim_extras)
 	chain = gcr_certificate_chain_new ();
 
 	/* Add two unrelated certificates */
-	gcr_certificate_chain_add (chain, cert_self);
-	gcr_certificate_chain_add (chain, cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_self);
+	gcr_certificate_chain_add (chain, test->cert_signed);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 2);
 
@@ -368,10 +396,11 @@ fetch_async_result (GObject *source, GAsyncResult *result, gpointer user_data)
 {
 	*((GAsyncResult**)user_data) = result;
 	g_object_ref (result);
-	testing_wait_stop ();
+	egg_test_wait_stop ();
 }
 
-TESTING_TEST (certificate_chain_complete_async)
+static void
+test_complete_async (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -380,13 +409,13 @@ TESTING_TEST (certificate_chain_complete_async)
 	chain = gcr_certificate_chain_new ();
 
 	/* Add a whole bunch of certificates */
-	gcr_certificate_chain_add (chain, cert_signed);
-	gcr_certificate_chain_add (chain, cert_ca);
-	gcr_certificate_chain_add (chain, cert_self);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_self);
 
 	gcr_certificate_chain_build_async (chain, GCR_PURPOSE_CLIENT_AUTH,
 	                                   NULL, 0, NULL, fetch_async_result, &result);
-	testing_wait_until (500);
+	egg_test_wait_until (500);
 	if (!gcr_certificate_chain_build_finish (chain, result, &error))
 		g_assert_not_reached ();
 	g_assert_no_error (error);
@@ -399,7 +428,8 @@ TESTING_TEST (certificate_chain_complete_async)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_anchor)
+static void
+test_with_anchor (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -407,9 +437,9 @@ TESTING_TEST (certificate_chain_with_anchor)
 	chain = gcr_certificate_chain_new ();
 
 	/* Two certificates in chain with ca trust anchor */
-	gcr_certificate_chain_add (chain, cert_signed);
-	gcr_certificate_chain_add (chain, cert_ca);
-	add_anchor_to_module (cert_ca, GCR_PURPOSE_CLIENT_AUTH);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_ca);
+	add_anchor_to_module (test->cert_ca, GCR_PURPOSE_CLIENT_AUTH);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 2);
 
@@ -421,12 +451,13 @@ TESTING_TEST (certificate_chain_with_anchor)
 	g_assert_cmpuint (gcr_certificate_chain_get_status (chain), ==,
 	                  GCR_CERTIFICATE_CHAIN_ANCHORED);
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 2);
-	g_assert (gcr_certificate_chain_get_anchor (chain) == cert_ca);
+	g_assert (gcr_certificate_chain_get_anchor (chain) == test->cert_ca);
 
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_anchor_and_lookup_ca)
+static void
+test_with_anchor_and_lookup_ca (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -434,9 +465,9 @@ TESTING_TEST (certificate_chain_with_anchor_and_lookup_ca)
 	chain = gcr_certificate_chain_new ();
 
 	/* One signed certificate, with CA in pkcs11, and trust anchor */
-	gcr_certificate_chain_add (chain, cert_signed);
-	add_certificate_to_module (cert_ca);
-	add_anchor_to_module (cert_ca, GCR_PURPOSE_CLIENT_AUTH);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	add_certificate_to_module (test->cert_ca);
+	add_anchor_to_module (test->cert_ca, GCR_PURPOSE_CLIENT_AUTH);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 1);
 
@@ -453,7 +484,8 @@ TESTING_TEST (certificate_chain_with_anchor_and_lookup_ca)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_pinned)
+static void
+test_with_pinned (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -461,9 +493,9 @@ TESTING_TEST (certificate_chain_with_pinned)
 	chain = gcr_certificate_chain_new ();
 
 	/* One certificate, and add CA to pkcs11 */
-	gcr_certificate_chain_add (chain, cert_signed);
-	gcr_certificate_chain_add (chain, cert_ca);
-	add_pinned_to_module (cert_signed, GCR_PURPOSE_CLIENT_AUTH, "pinned.example.com");
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	gcr_certificate_chain_add (chain, test->cert_ca);
+	add_pinned_to_module (test->cert_signed, GCR_PURPOSE_CLIENT_AUTH, "pinned.example.com");
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 2);
 
@@ -481,7 +513,8 @@ TESTING_TEST (certificate_chain_with_pinned)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_without_lookups)
+static void
+test_without_lookups (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
@@ -489,8 +522,8 @@ TESTING_TEST (certificate_chain_without_lookups)
 	chain = gcr_certificate_chain_new ();
 
 	/* One certificate, and add CA to pkcs11 */
-	gcr_certificate_chain_add (chain, cert_signed);
-	add_certificate_to_module (cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	add_certificate_to_module (test->cert_ca);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 1);
 
@@ -509,19 +542,20 @@ TESTING_TEST (certificate_chain_without_lookups)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_lookup_error)
+static void
+test_with_lookup_error (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
 
 	/* Make the lookup fail */
-	funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
+	test->funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
 
 	chain = gcr_certificate_chain_new ();
 
 	/* Two certificates in chain with ca trust anchor */
-	gcr_certificate_chain_add (chain, cert_signed);
-	add_certificate_to_module (cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	add_certificate_to_module (test->cert_ca);
 
 	g_assert_cmpuint (gcr_certificate_chain_get_length (chain), ==, 1);
 
@@ -537,19 +571,20 @@ TESTING_TEST (certificate_chain_with_lookup_error)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_anchor_error)
+static void
+test_with_anchor_error (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
 
 	/* Make the lookup fail */
-	funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
+	test->funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
 
 	chain = gcr_certificate_chain_new ();
 
 	/* Two certificates in chain with ca trust anchor */
-	gcr_certificate_chain_add (chain, cert_signed);
-	add_certificate_to_module (cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	add_certificate_to_module (test->cert_ca);
 
 	if (gcr_certificate_chain_build (chain, GCR_PURPOSE_CLIENT_AUTH,
 	                                 NULL, 0, NULL, &error))
@@ -563,24 +598,25 @@ TESTING_TEST (certificate_chain_with_anchor_error)
 	g_object_unref (chain);
 }
 
-TESTING_TEST (certificate_chain_with_anchor_error_async)
+static void
+test_with_anchor_error_async (Test *test, gconstpointer unused)
 {
 	GcrCertificateChain *chain;
 	GError *error = NULL;
 	GAsyncResult *result;
 
 	/* Make the lookup fail */
-	funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
+	test->funcs.C_GetAttributeValue = gck_mock_fail_C_GetAttributeValue;
 
 	chain = gcr_certificate_chain_new ();
 
 	/* Two certificates in chain with ca trust anchor */
-	gcr_certificate_chain_add (chain, cert_signed);
-	add_certificate_to_module (cert_ca);
+	gcr_certificate_chain_add (chain, test->cert_signed);
+	add_certificate_to_module (test->cert_ca);
 
 	gcr_certificate_chain_build_async (chain, GCR_PURPOSE_CLIENT_AUTH,
 	                                   NULL, 0, NULL, fetch_async_result, &result);
-	testing_wait_until (500);
+	egg_test_wait_until (500);
 	if (gcr_certificate_chain_build_finish (chain, result, &error))
 		g_assert_not_reached ();
 	g_assert_error (error, GCK_ERROR, CKR_FUNCTION_FAILED);
@@ -592,3 +628,28 @@ TESTING_TEST (certificate_chain_with_anchor_error_async)
 
 	g_object_unref (chain);
 }
+
+int
+main (int argc, char **argv)
+{
+	g_type_init ();
+	g_test_init (&argc, &argv, NULL);
+	g_set_prgname ("test-certificate-chain");
+
+	g_test_add ("/gcr/certificate-chain/new", Test, NULL, setup, test_new, teardown);
+	g_test_add ("/gcr/certificate-chain/new_with_cert", Test, NULL, setup, test_new_with_cert, teardown);
+	g_test_add ("/gcr/certificate-chain/selfsigned", Test, NULL, setup, test_selfsigned, teardown);
+	g_test_add ("/gcr/certificate-chain/incomplete", Test, NULL, setup, test_incomplete, teardown);
+	g_test_add ("/gcr/certificate-chain/empty", Test, NULL, setup, test_empty, teardown);
+	g_test_add ("/gcr/certificate-chain/trim_extras", Test, NULL, setup, test_trim_extras, teardown);
+	g_test_add ("/gcr/certificate-chain/complete_async", Test, NULL, setup, test_complete_async, teardown);
+	g_test_add ("/gcr/certificate-chain/with_anchor", Test, NULL, setup, test_with_anchor, teardown);
+	g_test_add ("/gcr/certificate-chain/with_anchor_and_lookup_ca", Test, NULL, setup, test_with_anchor_and_lookup_ca, teardown);
+	g_test_add ("/gcr/certificate-chain/with_pinned", Test, NULL, setup, test_with_pinned, teardown);
+	g_test_add ("/gcr/certificate-chain/without_lookups", Test, NULL, setup, test_without_lookups, teardown);
+	g_test_add ("/gcr/certificate-chain/with_lookup_error", Test, NULL, setup, test_with_lookup_error, teardown);
+	g_test_add ("/gcr/certificate-chain/with_anchor_error", Test, NULL, setup, test_with_anchor_error, teardown);
+	g_test_add ("/gcr/certificate-chain/with_anchor_error_async", Test, NULL, setup, test_with_anchor_error_async, teardown);
+
+	return egg_tests_run_in_thread_with_loop ();
+}
